robotpy-pathfinder
==================

.. image:: https://readthedocs.org/projects/robotpy-pathfinder/badge/?version=stable
   :target: http://robotpy-pathfinder.readthedocs.io/en/stable/?badge=stable
   :alt: Documentation Status

These are python bindings around Jaci R's PathFinder library. From the original
documentation:

Cross-Platform, Multi-Use Motion Profiling and Trajectory Generation.

Pathfinder is a library for generating Motion Profiles, a way to smoothly fit
and follow a trajectory based upon given waypoints.

Note: This requires C++ 11 and Python 3.5+

Usage
-----

Installation and usage documentation can be found at `http://robotpy-pathfinder.readthedocs.io <http://robotpy-pathfinder.readthedocs.io>`_
